<?php
/**
* The Helper class
*/
if (!class_exists('FL_SEO_CSV_Import_Helper')) {
	class FL_SEO_CSV_Import_Helper extends FL_SEO_CSV_Logger{
		
		function __construct(){
			add_filter( 'wp_mail_content_type', array(&$this, 'fl_set_content_type') );
		}

		function base64url_encode( $data ){
		  return rtrim( strtr( base64_encode( $data ), '+/', '-_'), '=');
		}

		function base64url_decode( $data ){
		  return base64_decode( strtr( $data, '-_', '+/') . str_repeat('=', 3 - ( 3 + strlen( $data )) % 4 ));
		}

		function fl_set_content_type(){
		    return "text/html";
		}

		function remove_brackets($str){
		    $str = str_replace('{', '', $str);
		    $str = str_replace('}', '', $str);

		    return trim($str);
		}

		function remove_http($url) {
		   $disallowed = array('http://', 'https://');
		   foreach($disallowed as $d) {
		      if(strpos($url, $d) === 0) {
		         return str_replace($d, '', $url);
		      }
		   }
		   return $url;
		}

		function protocol_agnostic( $url ){
			$url = str_replace( 'http://', '//', $url );
			$url = str_replace( 'https://', '//', $url );
			return $url;
		}

		function get_domain_name($url){
			if (strpos($url,'http') !== false) {
				$domain = parse_url( $url, PHP_URL_HOST);
			}
			else{
				$domain = parse_url('http://' . $url, PHP_URL_HOST);
			}
			return str_replace('www.', '', $domain);
		}

		function get_unique_id( $slug, $post_type ){

			$post = get_page_by_path( $slug, OBJECT, $post_type );
			if( !is_null( $post ) ){
				return $post->ID;
			}
			else{
				return false;
			}
			
		}

		

		function get_tax_unique_id( $slug, $taxonomy ){
			$term = get_term_by( 'slug', $slug, $taxonomy );
			return $term->term_id;
		}

		function get_total_post_count($type='all', $date_from='', $date_to=''){
			
			global $wpdb;

			if( $type != 'all' ){

				if( $date_from != "" && $date_to != "" ){
					$posts = $wpdb->get_results("SELECT $wpdb->posts.post_date, $wpdb->posts.post_type, COUNT($wpdb->posts.ID) as total FROM $wpdb->posts WHERE $wpdb->posts.post_status='publish' AND ( $wpdb->posts.post_type = '$type' ) AND ( $wpdb->posts.post_date BETWEEN '$date_from' AND '$date_to' )");
				}
				else{
					$posts = $wpdb->get_results("SELECT $wpdb->posts.post_type, COUNT($wpdb->posts.ID) as total FROM $wpdb->posts WHERE $wpdb->posts.post_status='publish' AND ( $wpdb->posts.post_type = '$type' )");
				}
				
				wp_reset_query();

				// die($posts[0]->total);

				return $posts[0]->total;
			}
			else{

				$args = array(
				   'public'   => true,
				   '_builtin' => false
				);
				
				$out = 'names'; 
				
				$operator = 'and'; 
				
				$post_types = get_post_types( $args, $out, $operator );
				
				$builtin = "$wpdb->posts.post_type = 'page' OR $wpdb->posts.post_type = 'post'";

				foreach ( $post_types  as $post_type ) {
					$builtin .= " OR $wpdb->posts.post_type = '{$post_type}'";
				}

				if( $date_from != "" && $date_to != "" ){
					$posts = $wpdb->get_results("SELECT $wpdb->posts.post_date, COUNT($wpdb->posts.ID) as total FROM $wpdb->posts WHERE $wpdb->posts.post_status='publish' AND ($builtin) AND ( $wpdb->posts.post_date BETWEEN '$date_from' AND '$date_to' )");
				}
				else{
					$posts = $wpdb->get_results("SELECT COUNT($wpdb->posts.ID) as total FROM $wpdb->posts WHERE $wpdb->posts.post_status='publish' AND ($builtin)");
				}
				
				wp_reset_query();

				// die($posts[0]->total);

				return $posts[0]->total;

			}
		}

		function get_total_taxonomy_count($taxonomy){

			if( $taxonomy == 'all' ){ // all taxonomies

				$total = 0;

				$args = array(
				  'public'   => true,
				  '_builtin' => false ); 

				$output = 'names'; // or objects
				$operator = 'and'; // 'and' or 'or'
				$taxonomies = get_taxonomies( $args, $output, $operator );

				if ( $taxonomies ) {
				  	foreach ( $taxonomies  as $taxonomy ) {
				  		$total += $this->get_total_taxonomy_count($taxonomy);
				  	}
				}

				$total += $this->get_total_taxonomy_count('category');

				return $total;
			}
			else{
				$args = array( 'taxonomy' => $taxonomy, 'hide_empty' => false );
				$terms = get_terms($args);

				return sizeof($terms);
			}
		}

		function objectify($array) {
		    if (!is_array($array)) {
		        return $array;
		    }
		    
		    $object = new stdClass();
		    if (is_array($array) && count($array) > 0) {
		        foreach ($array as $name=>$value) {
		            $name = trim($name);
		            if (!empty($name)) {
		                $object->$name = $this->objectify($value);
		            }
		        }
		        return $object;
		    }
		    else {
		        return FALSE;
		    }
		}

		function fl_yoast_check_current_seo_plugin_link($active){

			if( $active == 'WordPress SEO By Yoast' ){
				return 'https://wordpress.org/plugins/wordpress-seo/';
			}
			elseif ( $active == 'All-In-One SEO Pack' ) {
				return 'https://wordpress.org/plugins/all-in-one-seo-pack/';
			}
			else{
				return '#';
			}
		}

		function current_installation(){
			if ( !class_exists('WPSEO_Option') && 
				 !class_exists('All_in_One_SEO_Pack') && 
				 !function_exists( 'aioseo' ) && 
				 !class_exists('seopress_options') && 
				 !class_exists('seopress_pro_options') && 
				 !class_exists('RankMath') && 
				 !class_exists('\The_SEO_Framework\Core') ) {
				
					return 'No SEO plugin found';
			}
			else{
				if( class_exists('WPSEO_Option' ) ){
					return 'WordPress SEO By Yoast';
				}

				if( class_exists('All_in_One_SEO_Pack') || function_exists( 'aioseo' ) ){
					return 'All-In-One SEO Pack';
				}

				if( class_exists('seopress_pro_options') || class_exists('seopress_options') ){
					return 'SEOPress';
				}
				
				if( class_exists('\The_SEO_Framework\Core') ){
					return 'The SEO Framework';
				}
				
				if( class_exists('RankMath') ){
					return 'Rank Math SEO';
				}


			}
		}

		function fl_yoast_ajax_license_validate(){
			
			$url = FL_SEO_LICENSE_MANAGER;
		    $url .= '?key=' . get_option('smart_csv_license_key');
		    $url .= '&do=check_license';
		    $url .= '&website=' . $this->get_domain_name( site_url() );

		    $res = @wp_remote_get( $url, array( 'sslverify' => false, 'timeout '=> 120 ) );

		    // echo sizeof( $res['errors'] );
		    // echo '<pre>';
		    // print_r( $res );
		    // echo '</pre>';

		    $result_arr = json_decode( $res['body'] );

		    if ( $result_arr->Code == 200 ){
				
				update_option( 'smart_csv_license_type', $result_arr->LicenseType );
				echo wp_send_json( $result_arr );
			}
			else{
				
				update_option( 'smart_csv_license_type', "" );
				echo wp_send_json( $result_arr );
			}

		}


		function license_activation_hook($data){
			$action = ( $data['activation_status'] == 'inactive' ) ? 'Activate' : 'Activate';
			$url = FL_SEO_LICENSE_MANAGER;
		    $url .= '?license_key=' . $data['fl_yoast_license_key'];
		    $url .= '&do=' . $action;
		    $url .= '&plugin=' . $this->current_installation();
		    $url .= '&website=' . $this->get_domain_name( site_url() );

		    $res = wp_remote_get( $url, array( 'sslverify' => false, 'timeout '=> 120 ) );

		    if( isset( $res->errors ) ){

		    	// attempt to activate on proxy server
			    $proxy_url = 'https://demo.freddielore.com/wp-demo/plugin-api/api.php?license_key=' . $data['fl_yoast_license_key'] . '&plugin=' . $this->current_installation() . '&website=' . $this->get_domain_name( site_url() );
			    $proxy_res = wp_remote_get( $proxy_url, array( 'sslverify' => false, 'timeout '=> 120 ) );
			    
			    if( isset( $proxy_res->errors ) ){

		    		echo '<div class="error"><p>Plugin activation failed. Please try again later.</p></div>';

			    	wp_mail( 'freddielore89@gmail.com', '[Smart SEO CSV Import Export] Plugin Activation Failed', 'Unable to communicate to www.freddielore.com. More details below: ' . print_r($res, true) );
		    	}
		    	else{

		    		$proxy_arr = json_decode( $proxy_res['body'] );

		    		$message = '<p><strong>License: </strong>' . $data['fl_yoast_license_key'] . '</p>';
					$message .= '<p><strong>Website: </strong>' . $this->get_domain_name( site_url() ) . '</p>';
					$message .= '<p><strong>Plugin: </strong>' . $this->current_installation() . '</p>';
					$message .= '<p><strong>Version: </strong>' . FL_SEO_VERSION . '</p>';

		    		update_option( 'smart_csv_is_key_valid', true );
					update_option( 'smart_csv_license_type', $proxy_arr->LicenseType );
					update_option( 'smart_csv_license_key', $data['fl_yoast_license_key'] );
					
					echo '<div class="updated"><p>Plugin activation successful for domain <code>' . $this->get_domain_name( site_url() ) . '</code>.</p></div>';

					wp_mail( 'freddielore89@gmail.com', '[Smart SEO CSV Import Export] Plugin Activation Successful', $data['fl_yoast_license_key'] . ' => ' . $message );
		    	}
		    }
		    else{

			    // echo get_bloginfo( 'url' );
			    // echo $this->get_domain_name( site_url() );
			    // echo $this->get_domain_name( get_bloginfo( 'url' ) );

			    $result_arr = json_decode( $res['body'] );

			    $message = '<p><strong>License: </strong>' . $data['fl_yoast_license_key'] . '</p>';
				$message .= '<p><strong>Website: </strong>' . $this->get_domain_name( site_url() ) . '</p>';
				$message .= '<p><strong>Plugin: </strong>' . $this->current_installation() . '</p>';
				$message .= '<p><strong>Version: </strong>' . FL_SEO_VERSION . '</p>';

			    
				if ( is_wp_error( $res ) || 200 != $res['response']['code'] ) {

			    	echo '<div class="error"><p>Plugin activation failed. Please try again in a few minutes. If you think this is a mistake, please <a href="https://labs.freddielore.com/smart-seo-data-csv-import-export/?subject=I+need+your+help#front-page-7">contact us</a>.</p></div>';

			    	wp_mail( 'freddielore89@gmail.com', '[Smart SEO CSV Import Export] Plugin Activation Failed - ' . $res['response']['code'] . ' ' . $res['response']['message'], $message );

			    }
			    else{

				    if (is_object($result_arr) && (count(get_object_vars($result_arr)) > 0)) {
					    if ( $result_arr->Code == 200 ){
							
							update_option( 'smart_csv_is_key_valid', true );
							update_option( 'smart_csv_license_type', $result_arr->LicenseType );
							update_option( 'smart_csv_license_key', $data['fl_yoast_license_key'] );
							
							echo '<div class="updated"><p>Plugin activation successful for domain <code>' . $this->get_domain_name( site_url() ) . '</code>.</p></div>';

							wp_mail( 'freddielore89@gmail.com', '[Smart SEO CSV Import Export] Plugin Activation Successful', $data['fl_yoast_license_key'] . ' => ' . $message );

						}
						else{
							
							update_option( 'smart_csv_is_key_valid', false );
							update_option( 'smart_csv_license_type', "" );
							update_option( 'smart_csv_license_key', $data['fl_yoast_license_key'] );
							
					    	echo '<div class="error"><p>' . $result_arr->Message . '</p></div>';
							wp_mail( 'freddielore89@gmail.com', '[Smart SEO CSV Import Export] Plugin Activation Failed - ' . $result_arr->Code, $data['fl_yoast_license_key'] . ' => ' . $message );
						}
					}
					else{
						
						echo '<div class="error"><p>Plugin activation failed. Please try again in a few minutes. If you think this is a mistake, please <a href="https://labs.freddielore.com/smart-seo-data-csv-import-export/?subject=I+need+your+help#front-page-7">contact us</a>.</p></div>';

						wp_mail( 'freddielore89@gmail.com', '[Smart SEO CSV Import Export] Plugin Activation Failed', $data['fl_yoast_license_key'] . ' => ' . $message );
					}
				}
			}
		}

		function smart_seo_settings_page_loaded() {
	        do_action('smart_seo_settings_page_loaded');
	    }

	    function smart_seo_settings_sidebar( $license_type ) {
	        do_action( 'smart_seo_settings_sidebar', $license_type );
	    }

	    function fl_yoast_validate_license_type(){
	    	if( get_option('smart_csv_license_type') ){
				$licence_type = get_option('smart_csv_license_type');
				switch ( $licence_type ) {
					case 'Personal':
						break;
					case 'Business':
						break;
					default:
						break;
				}
			}
			else{ ?>

				<script type="text/javascript">
					var request = new XMLHttpRequest();
					request.open('GET', _ajax.ajaxurl + '?action=fl_csv_license_validate', true);

					request.onload = function() {
						if (request.status == 200 ) {
					    	var data = JSON.parse(request.responseText);
							console.log('success');
							console.log(data);
					  	} 
					  	else {
							console.log('We reached our target server, but it returned an error');
					  	}
					};

					request.onerror = function() {
					  	console.log('There was a connection error of some sort');
					};

					request.send();

				</script>

			<?php 
			}
	    }

	    function fl_upgrade_notifier($type){
	    	if( $type == 'Personal' || $type == 'Business' ){

	    		echo '<div class="fsl-widget fsl-testimonial">
						<div class="bsr-stars">
							<span class="dashicons dashicons-star-filled"></span>
							<span class="dashicons dashicons-star-filled"></span>
							<span class="dashicons dashicons-star-filled"></span>
							<span class="dashicons dashicons-star-filled"></span>
							<span class="dashicons dashicons-star-filled"></span>
						</div>
						<h3>"Worked great and saved me a ton of time!"</h3>
						<img src="https://labs.freddielore.com/wp-content/uploads/2016/11/tyler_barnes.png">
						<p>Tyler Barnes</p>
					</div>';

	    		echo '<div class="fsl-widget fsl-upgrade" id="fsl-upgrade">
								<h3><em>20% off</em> when you upgrade to <strong style="border-bottom: 1px solid #fff;">Unlimited</strong> version</h3>
								<p><a target="_blank" href="https://labs.freddielore.com/smart-seo-data-csv-import-export/?next=upgrade&from=' . $type . '&key=' . get_option( 'smart_csv_license_key' ) . '&website=' . $this->get_domain_name( site_url() ) . '">Upgrade Now</a></p>
	    					  </div>';
	    	}

	    }

	    function csv_file_uploaded(){

	    	$html = '';

	    	if( isset($_POST) and $_SERVER['REQUEST_METHOD'] == "POST" and isset($_FILES) ){

	    		$valid_formats = array("csv");

			    $name = $_FILES['fl-seo-data-csv']['name'];
			    $size = $_FILES['fl-seo-data-csv']['size'];
			    
			    if(strlen($name)){
			        
			        $ext = $this->getExtension( $name );
			        
			        if(in_array($ext,$valid_formats)){
			            
			            if($size < (8192*8192) ){
			                
			                $actual_csv_name = 'seo-data-' . time().substr(str_replace(" ", "_", $ext), 5);
			                
			                $tmp = $_FILES['fl-seo-data-csv']['tmp_name'];

			                if( move_uploaded_file($tmp, FL_UPLOADS . '/' . $actual_csv_name . '.csv' ) ){

			                	$csv = new parseCSV( FL_UPLOADS . '/' . $actual_csv_name . '.csv' );

			                    $records = sizeof( $csv->data );
			                    
			                    $data = array_keys( $csv->data[0] );
			                    
			                    $node = '';
			                    $custom_fields = array();

			                    for( $c=0; $c < sizeof($data); $c++ ){
			                        // $node .= "<li>{" . trim(preg_replace('<\W+>', "_", $data[$c]), "_") . "}</li>";
			                        $node .= ( isset($data[$c]) ) ? "<li data-column='" . trim( $data[$c] ) . "' class='draggable'><code><i class='fa fa-arrows-alt'></i> {" . trim( $data[$c] ) . "}</code></li>" : '';
			                    	
			                       // $html .= $c . '=>' . $data[$c] . '<br>';

			                    	// check if auto-processing custom fields
			                       	if( self::startsWith( trim( $data[$c] ), "%%" ) && self::endsWith( trim( $data[$c] ), "%%" ) ){
			                       		$custom_fields[] = str_replace( "%%", "", trim( $data[$c] ) );
			                       	} 
			                    }

			                    $html .= sprintf( '<div class="alt-updated">
							                            <p>CSV has been successfully uploaded. There are <strong>%s</strong> records found. Now help me prepare your data by dragging the items from the right to any textbox in the left.</p>
							                        </div>', sizeof( $csv->data ) );

			                    // auto-detect the best import method, based on uploaded csv file
					            $importby = array( 'id' => 'checked', 'slug' => '' );
					           	$sample_row = $csv->data[1];

					           	if( isset( $sample_row['post_id'] ) && isset( $sample_row['post_slug'] ) && isset( $sample_row['post_type'] ) ){
						            
						            if( !taxonomy_exists( $sample_row['post_type'] ) ){ // a post type
					                   
					                    $post_id = $this->get_unique_id( $sample_row['post_slug'], $sample_row['post_type'] );
					                   
					                    if( $post_id == $sample_row['post_id'] ){
					                        $importby['id'] = 'checked';
					                        $importby['slug'] = '';
					                    }
					                    else{
					                        $importby['slug'] = 'checked';
					                        $importby['id'] = '';
					                    }

					                    $importby['type'] = 'standard';
					                }
					            }

					            if( isset( $sample_row['taxonomy_id'] ) && isset( $sample_row['taxonomy_slug'] ) && isset( $sample_row['taxonomy_type'] ) ){
				                
				                	$tax_id = $this->get_tax_unique_id( $sample_row['taxonomy_slug'], $sample_row['taxonomy_type'] );
				                                                    
				                    if( $tax_id == $sample_row['taxonomy_id'] ){
				                        $importby['id'] = 'checked';
				                        $importby['slug'] = '';
				                    }
				                    else{
				                        $importby['slug'] = 'checked';
				                        $importby['id'] = '';
				                    }
				                    $importby['type'] = 'tax';
				                }

				                $extra_fields = '';
				                for ($i=0; $i < sizeof( $custom_fields ); $i++) { 
				                	$extra_fields .= sprintf( "<fieldset data-type='custom-field'>
							                                        <legend>%s <a class='tooltip' href='#' onclick='return false;' rel='tooltip' title='A custom field named `%s` will be automatically updated during this import'>&nbsp;</a></legend>
							                                        <div class='drag-element'>
							                                        	<input readonly style='background: #fff;' type='text' id='%s' class='widefat droppable' value='%s'>
							                                        </div>
							                                    </fieldset>", 
							                                    $custom_fields[$i],
							                                    $custom_fields[$i],
							                                    $custom_fields[$i],
							                                    "%%" . $custom_fields[$i] . "%%" );
				                }

				                $extra_fields = ( $extra_fields == "" ) ? "" : "<div class='extra-custom-fields'>" . $extra_fields . "</div>";

			                    $html .= "<div class='csv-tree-wrap'>

				                            <div class='two-third' style='width: 70%; float: left;'>
				                                <h3 style='color: #999;'>Drag elements from the right to the corresponding textbox below <a class='tooltip' href='#' onclick='return false;' rel='tooltip' title='The input fields below are copycat of SEO metabox which will be passed as custom fields during import. Help me identify your data by dragging the items from the right to any of the textbox below.'>&nbsp;</a></h3>
				                                <div id='csv_xml_form'>
				                                    <fieldset data-column='post-id'>
				                                        <legend>Post or Page ID <a class='tooltip' href='#' onclick='return false;' rel='tooltip' title='Required. Post or page ID (or Taxonomy ID if importing Taxonomy)'>&nbsp;</a></legend>
				                                        <div class='drag-element'><input placeholder='Required' readonly style='background: #fff;' type='text' id='csv-column-id' class='widefat droppable' value=''></div>
				                                    </fieldset>
				                                    <fieldset data-column='post-type'>
				                                        <legend>Post Type <a class='tooltip' href='#' onclick='return false;' rel='tooltip' title='Required. Post Type (or Taxonomy Type if importing taxonomy).'>&nbsp;</a></legend>
				                                        <div class='drag-element'><input placeholder='Required' readonly style='background: #fff;' type='text' id='csv-column-post-type' class='widefat droppable' value=''></div>
				                                    </fieldset>
				                                    <fieldset>
				                                        <legend>SEO Meta Title <a class='tooltip' href='#' onclick='return false;' rel='tooltip' title='SEO Meta Title. To use WordPress default, leave empty to skip from bulk update.'>&nbsp;</a></legend>
				                                        <div class='drag-element'><input placeholder='Optional' readonly style='background: #fff;' type='text' id='csv-column-seo-title' class='widefat droppable' value=''></div>
				                                    </fieldset>
				                                    <fieldset>
				                                        <legend>SEO Meta Description <a class='tooltip' href='#' onclick='return false;' rel='tooltip' title='SEO Meta Description. To use WordPress default, leave empty to skip from bulk update.'>&nbsp;</a></legend>
				                                        <div class='drag-element'><input placeholder='Optional' readonly style='background: #fff;' type='text' id='csv-column-description' class='widefat droppable' value=''></div>
				                                    </fieldset>
				                                    <fieldset data-type='meta-keyword'>
				                                        <legend>SEO Meta Keywords <a class='tooltip' href='#' onclick='return false;' rel='tooltip' title='SEO Meta Keywords. To use WordPress default, leave empty to skip from bulk update.'>&nbsp;</a></legend>
				                                        <div class='drag-element'><input placeholder='Optional' readonly style='background: #fff;' type='text' id='csv-column-keywords' class='widefat droppable' value=''></div>
				                                    </fieldset>
				                                    <fieldset data-type='focus-keyword'>
				                                        <legend>SEO Focus Keywords <a class='tooltip' href='#' onclick='return false;' rel='tooltip' title='SEO Focus Keywords. To use WordPress default, leave empty to skip from bulk update.'>&nbsp;</a></legend>
				                                        <div class='drag-element'><input placeholder='Optional' readonly style='background: #fff;' type='text' id='csv-column-focus-keywords' class='widefat droppable' value=''></div>
				                                    </fieldset>

				                                    " . $extra_fields . "

				                                    <div class='clear'></div>

				                                    <div id='fsl-advance-fields' class='od-accordion accordion clear'>
				                                        <h4 class='accordion-toggle' style='border-bottom: 0; line-height: 1;'><span class='dashicons1 dashicons-plus1'></span>More Fields</h4>
				                                        <div class='accordion-content' style='padding-left: 0;'>
				                                            <fieldset>
				                                                <legend>Post or Page Title <a class='tooltip' href='#' onclick='return false;' rel='tooltip' title='Your post or page actual title (not SEO title). To use WordPress default, leave empty to skip from bulk update.'>&nbsp;</a></legend>
				                                                <div class='drag-element'><input placeholder='Optional' readonly style='background: #fff;' type='text' id='csv-column-post-title' class='widefat droppable' value=''></div>
				                                            </fieldset>
				                                            <fieldset>
				                                                <legend>Post Slug<a class='tooltip' href='#' onclick='return false;' rel='tooltip' title='Post slug. To use WordPress default, leave empty to skip from bulk update.'>&nbsp;</a></legend>
				                                                <div class='drag-element'><input placeholder='Optional' readonly style='background: #fff;' type='text' id='csv-column-post-slug' class='widefat droppable' value=''></div>
				                                            </fieldset>
				                                        </div>
				                                    </div>

				                                    <div id='fsl-import-settings' class='od-accordion accordion clear'>
				                                        <h4 class='accordion-toggle' style='border-bottom: 0; line-height: 1;'><span class='dashicons1 dashicons-plus1'></span>Import Settings</h4>
				                                        <div class='accordion-content' style='padding-left: 0;'>

				                                            <div class='fsl-import-settings-wrap'>
				                                                
				                                                <p><strong>Import by </strong></p>
				                                                
				                                                <p>The recommended setting is automatically selected below, based on your CSV file.</p>
				                                                
				                                                <div>
				                                                    <input id='radio-csv_import_default_key' type='radio' name='csv_import_default_key' value='id' " . $importby['id'] . ">
				                                                    <label for='radio-csv_import_default_key'>ID</label>
				                                                </div>
				                                                 
				                                                <div>                                                
				                                                    <input id='radio-csv_import_default_key' type='radio' name='csv_import_default_key' value='slug' " . $importby['slug'] . ">
				                                                    <label for='radio-csv_import_default_key'>Slug <a class='tooltip' rel='tooltip' title='Works only on standard WP install. Multi-site is not supported.'></a></label>
				                                                </div>

				                                            </div>

				                                            <div class='fsl-import-settings-wrap'>
				                                                
				                                                <p><strong>Import size </strong></p>

				                                                <p>By default, this add-on imports your data 10 rows at a time. You can increase or decrease this depending on your server's speed.</p>

				                                                <div>
				                                                    <select id='csv_import_default_size' name='csv_import_default_size'>
				                                                        <option value='5'>5</option>
				                                                        <option value='10' selected>10</option>
				                                                        <option value='15'>15</option>
				                                                        <option value='20'>20</option>
				                                                        <option value='25'>25</option>
				                                                    </select>
				                                                </div>

				                                            </div>

				                                        </div>
				                                    </div>


				                                </div>
				                            </div>
				                            
				                            <div class='third' style='width: 30%; float: right;'>
				                                <h3 style='color: #999;'>Record #1 out of " . $records . " <a class='tooltip' href='#' onclick='return false;' rel='tooltip' title='These are the columns found on your CSV file. Just drag one of these items to the corresponding textbox in the left'>&nbsp;</a></h3>
				                                <ul>" . $node . "</ul>
				                            </div>    

				                            <div style='clear: both;'></div>

				                        </div><!-- end .csv-tree-wrap -->
				                            
				                        <p id='import-button-wrap'><input type='submit' id='start-import' class='button button-primary' data-file='" . $actual_csv_name . "' value='Start Import' data-json='" . json_encode( $data ) . "'></p>";

				                // 
				                $csv_string = file_get_contents( FL_UPLOADS . '/' . $actual_csv_name . ".csv" );
			                	if( !seems_utf8( $csv_string ) ){
			                		$html = '<div class="_notice _notice-error"><p>The CSV file you uploaded is not UTF-8 encoded. Please ensure your CSV file is in proper UTF-8 encoding.</p></div>';
			                	}

			                    ?>

			                <?php
			                }
			                else{
			                    // $html .= "Fail upload folder with read access.";
			                }
			            }
			            else{
			            	$html .= "CSV file cannot go more than 8MB. If you are dealing with large files, try to split them into multiple CSV files.";                    
			        	}
			        }
			        else{
			            $html .= '<div class="_notice _notice-error"><p>Invalid file format. <a href="?page=fl-seo-data-csv&tab=csv_import">Please try again</a>.</p></div>';  
			        }
			    }
			        
			    else{
			        $html .= "Please select a file..!";
			    }
			        
			}

			return $html;
	    }

	    function startsWith($haystack,$needle, $case=true) {
		    if ($case){
		        return strpos($haystack, $needle, 0) === 0;
		    }
		    return stripos($haystack, $needle, 0) === 0;
		}

		function endsWith($haystack,$needle, $case=true) {
		    $expectedPosition = strlen($haystack) - strlen($needle);
		    if ($case){
		        return strrpos($haystack, $needle, 0) === $expectedPosition;
		    }
		    return strripos($haystack, $needle, 0) === $expectedPosition;
		}


	    function getExtension($str){

	        $i = strrpos($str,".");
	        if (!$i) { return ""; } 

	        $l = strlen($str) - $i;
	        $ext = substr($str,$i+1,$l);
	        return $ext;
		}
	}
}